@@ -47,8 +47,8 @@ class ExportContainer(BaseContainer):
 
         objects = [
             instance for instance in objects
-            if ID.from_object(instance) not in self.__instance_map
-            and self.policy.should_export_object(instance)
+            if ID.from_object(instance) not in self.__instance_map and
+            self.policy.should_export_object(instance)
         ]
 
         if not objects:
